@@ -1,13 +1,14 @@
 from .prediction_input import PredictionInput
 from .batch_prediction_version import BatchPredictionVersion
+from .refresh_schedule import RefreshSchedule
 
 
 class BatchPrediction():
     '''
-
+        Batch predictions
     '''
 
-    def __init__(self, client, batchPredictionId=None, createdAt=None, name=None, deploymentId=None, fileConnectorOutputLocation=None, globalPredictionArgs=None, databaseConnectorId=None, databaseOutputConfiguration=None, explanations=None, fileOutputFormat=None, connectorType=None, legacyInputLocation=None, refreshSchedules=None, batchInputs={}, latestBatchPredictionVersion={}):
+    def __init__(self, client, batchPredictionId=None, createdAt=None, name=None, deploymentId=None, fileConnectorOutputLocation=None, globalPredictionArgs=None, databaseConnectorId=None, databaseOutputConfiguration=None, explanations=None, fileOutputFormat=None, connectorType=None, legacyInputLocation=None, batchInputs={}, latestBatchPredictionVersion={}, refreshSchedules={}):
         self.client = client
         self.id = batchPredictionId
         self.batch_prediction_id = batchPredictionId
@@ -22,25 +23,26 @@ class BatchPrediction():
         self.file_output_format = fileOutputFormat
         self.connector_type = connectorType
         self.legacy_input_location = legacyInputLocation
-        self.refresh_schedules = refreshSchedules
         self.batch_inputs = client._build_class(PredictionInput, batchInputs)
         self.latest_batch_prediction_version = client._build_class(
             BatchPredictionVersion, latestBatchPredictionVersion)
+        self.refresh_schedules = client._build_class(
+            RefreshSchedule, refreshSchedules)
 
     def __repr__(self):
-        return f"BatchPrediction(batch_prediction_id={repr(self.batch_prediction_id)}, created_at={repr(self.created_at)}, name={repr(self.name)}, deployment_id={repr(self.deployment_id)}, file_connector_output_location={repr(self.file_connector_output_location)}, global_prediction_args={repr(self.global_prediction_args)}, database_connector_id={repr(self.database_connector_id)}, database_output_configuration={repr(self.database_output_configuration)}, explanations={repr(self.explanations)}, file_output_format={repr(self.file_output_format)}, connector_type={repr(self.connector_type)}, legacy_input_location={repr(self.legacy_input_location)}, refresh_schedules={repr(self.refresh_schedules)}, batch_inputs={repr(self.batch_inputs)}, latest_batch_prediction_version={repr(self.latest_batch_prediction_version)})"
+        return f"BatchPrediction(batch_prediction_id={repr(self.batch_prediction_id)}, created_at={repr(self.created_at)}, name={repr(self.name)}, deployment_id={repr(self.deployment_id)}, file_connector_output_location={repr(self.file_connector_output_location)}, global_prediction_args={repr(self.global_prediction_args)}, database_connector_id={repr(self.database_connector_id)}, database_output_configuration={repr(self.database_output_configuration)}, explanations={repr(self.explanations)}, file_output_format={repr(self.file_output_format)}, connector_type={repr(self.connector_type)}, legacy_input_location={repr(self.legacy_input_location)}, batch_inputs={repr(self.batch_inputs)}, latest_batch_prediction_version={repr(self.latest_batch_prediction_version)}, refresh_schedules={repr(self.refresh_schedules)})"
 
     def __eq__(self, other):
         return self.__class__ == other.__class__ and self.id == other.id
 
     def to_dict(self):
-        return {'batch_prediction_id': self.batch_prediction_id, 'created_at': self.created_at, 'name': self.name, 'deployment_id': self.deployment_id, 'file_connector_output_location': self.file_connector_output_location, 'global_prediction_args': self.global_prediction_args, 'database_connector_id': self.database_connector_id, 'database_output_configuration': self.database_output_configuration, 'explanations': self.explanations, 'file_output_format': self.file_output_format, 'connector_type': self.connector_type, 'legacy_input_location': self.legacy_input_location, 'refresh_schedules': self.refresh_schedules, 'batch_inputs': [elem.to_dict() for elem in self.batch_inputs or []], 'latest_batch_prediction_version': [elem.to_dict() for elem in self.latest_batch_prediction_version or []]}
+        return {'batch_prediction_id': self.batch_prediction_id, 'created_at': self.created_at, 'name': self.name, 'deployment_id': self.deployment_id, 'file_connector_output_location': self.file_connector_output_location, 'global_prediction_args': self.global_prediction_args, 'database_connector_id': self.database_connector_id, 'database_output_configuration': self.database_output_configuration, 'explanations': self.explanations, 'file_output_format': self.file_output_format, 'connector_type': self.connector_type, 'legacy_input_location': self.legacy_input_location, 'batch_inputs': [elem.to_dict() for elem in self.batch_inputs or []], 'latest_batch_prediction_version': [elem.to_dict() for elem in self.latest_batch_prediction_version or []], 'refresh_schedules': self.refresh_schedules.to_dict() if self.refresh_schedules else None}
 
     def start(self):
         return self.client.start_batch_prediction(self.batch_prediction_id)
 
     def refresh(self):
-        self = self.describe()
+        self.__dict__.update(self.describe().__dict__)
         return self
 
     def describe(self):
@@ -64,8 +66,11 @@ class BatchPrediction():
     def set_dataset(self, dataset_type, dataset_id=None):
         return self.client.set_batch_prediction_dataset(self.batch_prediction_id, dataset_type, dataset_id)
 
-    def set_feature_group(self, dataset_type, feature_group_id=None):
-        return self.client.set_batch_prediction_feature_group(self.batch_prediction_id, dataset_type, feature_group_id)
+    def set_feature_group(self, feature_group_type, feature_group_id=None):
+        return self.client.set_batch_prediction_feature_group(self.batch_prediction_id, feature_group_type, feature_group_id)
+
+    def set_dataset_remap(self, dataset_id_remap):
+        return self.client.set_batch_prediction_dataset_remap(self.batch_prediction_id, dataset_id_remap)
 
     def delete(self):
         return self.client.delete_batch_prediction(self.batch_prediction_id)
