@@ -1,12 +1,14 @@
+from .refresh_schedule import RefreshSchedule
+from .dataset_column import DatasetColumn
 from .dataset_version import DatasetVersion
 
 
 class Dataset():
     '''
-
+        A dataset reference
     '''
 
-    def __init__(self, client, datasetId=None, name=None, sourceType=None, dataSource=None, createdAt=None, refreshSchedules=None, ignoreBefore=None, ephemeral=None, lookbackDays=None, databaseConnectorId=None, databaseConnectorConfig=None, connectorType=None, datasetTableName=None, applicationConnectorId=None, applicationConnectorConfig=None, latestDatasetVersion={}):
+    def __init__(self, client, datasetId=None, name=None, sourceType=None, dataSource=None, createdAt=None, ignoreBefore=None, ephemeral=None, lookbackDays=None, databaseConnectorId=None, databaseConnectorConfig=None, connectorType=None, datasetTableName=None, applicationConnectorId=None, applicationConnectorConfig=None, schema={}, refreshSchedules={}, latestDatasetVersion={}):
         self.client = client
         self.id = datasetId
         self.dataset_id = datasetId
@@ -14,7 +16,6 @@ class Dataset():
         self.source_type = sourceType
         self.data_source = dataSource
         self.created_at = createdAt
-        self.refresh_schedules = refreshSchedules
         self.ignore_before = ignoreBefore
         self.ephemeral = ephemeral
         self.lookback_days = lookbackDays
@@ -24,17 +25,23 @@ class Dataset():
         self.dataset_table_name = datasetTableName
         self.application_connector_id = applicationConnectorId
         self.application_connector_config = applicationConnectorConfig
+        self.schema = client._build_class(DatasetColumn, schema)
+        self.refresh_schedules = client._build_class(
+            RefreshSchedule, refreshSchedules)
         self.latest_dataset_version = client._build_class(
             DatasetVersion, latestDatasetVersion)
 
     def __repr__(self):
-        return f"Dataset(dataset_id={repr(self.dataset_id)}, name={repr(self.name)}, source_type={repr(self.source_type)}, data_source={repr(self.data_source)}, created_at={repr(self.created_at)}, refresh_schedules={repr(self.refresh_schedules)}, ignore_before={repr(self.ignore_before)}, ephemeral={repr(self.ephemeral)}, lookback_days={repr(self.lookback_days)}, database_connector_id={repr(self.database_connector_id)}, database_connector_config={repr(self.database_connector_config)}, connector_type={repr(self.connector_type)}, dataset_table_name={repr(self.dataset_table_name)}, application_connector_id={repr(self.application_connector_id)}, application_connector_config={repr(self.application_connector_config)}, latest_dataset_version={repr(self.latest_dataset_version)})"
+        return f"Dataset(dataset_id={repr(self.dataset_id)}, name={repr(self.name)}, source_type={repr(self.source_type)}, data_source={repr(self.data_source)}, created_at={repr(self.created_at)}, ignore_before={repr(self.ignore_before)}, ephemeral={repr(self.ephemeral)}, lookback_days={repr(self.lookback_days)}, database_connector_id={repr(self.database_connector_id)}, database_connector_config={repr(self.database_connector_config)}, connector_type={repr(self.connector_type)}, dataset_table_name={repr(self.dataset_table_name)}, application_connector_id={repr(self.application_connector_id)}, application_connector_config={repr(self.application_connector_config)}, schema={repr(self.schema)}, refresh_schedules={repr(self.refresh_schedules)}, latest_dataset_version={repr(self.latest_dataset_version)})"
 
     def __eq__(self, other):
         return self.__class__ == other.__class__ and self.id == other.id
 
     def to_dict(self):
-        return {'dataset_id': self.dataset_id, 'name': self.name, 'source_type': self.source_type, 'data_source': self.data_source, 'created_at': self.created_at, 'refresh_schedules': self.refresh_schedules, 'ignore_before': self.ignore_before, 'ephemeral': self.ephemeral, 'lookback_days': self.lookback_days, 'database_connector_id': self.database_connector_id, 'database_connector_config': self.database_connector_config, 'connector_type': self.connector_type, 'dataset_table_name': self.dataset_table_name, 'application_connector_id': self.application_connector_id, 'application_connector_config': self.application_connector_config, 'latest_dataset_version': [elem.to_dict() for elem in self.latest_dataset_version or []]}
+        return {'dataset_id': self.dataset_id, 'name': self.name, 'source_type': self.source_type, 'data_source': self.data_source, 'created_at': self.created_at, 'ignore_before': self.ignore_before, 'ephemeral': self.ephemeral, 'lookback_days': self.lookback_days, 'database_connector_id': self.database_connector_id, 'database_connector_config': self.database_connector_config, 'connector_type': self.connector_type, 'dataset_table_name': self.dataset_table_name, 'application_connector_id': self.application_connector_id, 'application_connector_config': self.application_connector_config, 'schema': [elem.to_dict() for elem in self.schema or []], 'refresh_schedules': self.refresh_schedules.to_dict() if self.refresh_schedules else None, 'latest_dataset_version': [elem.to_dict() for elem in self.latest_dataset_version or []]}
+
+    def get_schema(self):
+        return self.client.get_dataset_schema(self.dataset_id)
 
     def create_version_from_file_connector(self, location=None, file_format=None, csv_delimiter=None):
         return self.client.create_dataset_version_from_file_connector(self.dataset_id, location, file_format, csv_delimiter)
@@ -42,8 +49,8 @@ class Dataset():
     def create_version_from_database_connector(self, object_name=None, columns=None, query_arguments=None, sql_query=None):
         return self.client.create_dataset_version_from_database_connector(self.dataset_id, object_name, columns, query_arguments, sql_query)
 
-    def create_version_from_application_connector(self, object_id=None, start_date=None, end_date=None):
-        return self.client.create_dataset_version_from_application_connector(self.dataset_id, object_id, start_date, end_date)
+    def create_version_from_application_connector(self, object_id=None, start_timestamp=None, end_timestamp=None):
+        return self.client.create_dataset_version_from_application_connector(self.dataset_id, object_id, start_timestamp, end_timestamp)
 
     def create_version_from_upload(self, file_format=None):
         return self.client.create_dataset_version_from_upload(self.dataset_id, file_format)
@@ -51,14 +58,11 @@ class Dataset():
     def snapshot_streaming_data(self):
         return self.client.snapshot_streaming_data(self.dataset_id)
 
-    def create_version(self, location=None, file_format=None, csv_delimiter=None):
-        return self.client.create_dataset_version(self.dataset_id, location, file_format, csv_delimiter)
-
-    def create_version_from_local_file(self, file_format=None):
-        return self.client.create_dataset_version_from_local_file(self.dataset_id, file_format)
+    def set_column_data_type(self, column, data_type):
+        return self.client.set_dataset_column_data_type(self.dataset_id, column, data_type)
 
     def refresh(self):
-        self = self.describe()
+        self.__dict__.update(self.describe().__dict__)
         return self
 
     def describe(self):
