@@ -1,13 +1,14 @@
-from .model_location import ModelLocation
 from .model_version import ModelVersion
+from .model_location import ModelLocation
+from .refresh_schedule import RefreshSchedule
 
 
 class Model():
     '''
-
+        A model
     '''
 
-    def __init__(self, client, name=None, modelId=None, modelConfig=None, createdAt=None, projectId=None, shared=None, sharedAt=None, refreshSchedules=None, location={}, latestModelVersion={}):
+    def __init__(self, client, name=None, modelId=None, modelConfig=None, createdAt=None, projectId=None, shared=None, sharedAt=None, location={}, refreshSchedules={}, latestModelVersion={}):
         self.client = client
         self.id = modelId
         self.name = name
@@ -17,30 +18,37 @@ class Model():
         self.project_id = projectId
         self.shared = shared
         self.shared_at = sharedAt
-        self.refresh_schedules = refreshSchedules
         self.location = client._build_class(ModelLocation, location)
+        self.refresh_schedules = client._build_class(
+            RefreshSchedule, refreshSchedules)
         self.latest_model_version = client._build_class(
             ModelVersion, latestModelVersion)
 
     def __repr__(self):
-        return f"Model(name={repr(self.name)}, model_id={repr(self.model_id)}, model_config={repr(self.model_config)}, created_at={repr(self.created_at)}, project_id={repr(self.project_id)}, shared={repr(self.shared)}, shared_at={repr(self.shared_at)}, refresh_schedules={repr(self.refresh_schedules)}, location={repr(self.location)}, latest_model_version={repr(self.latest_model_version)})"
+        return f"Model(name={repr(self.name)}, model_id={repr(self.model_id)}, model_config={repr(self.model_config)}, created_at={repr(self.created_at)}, project_id={repr(self.project_id)}, shared={repr(self.shared)}, shared_at={repr(self.shared_at)}, location={repr(self.location)}, refresh_schedules={repr(self.refresh_schedules)}, latest_model_version={repr(self.latest_model_version)})"
 
     def __eq__(self, other):
         return self.__class__ == other.__class__ and self.id == other.id
 
     def to_dict(self):
-        return {'name': self.name, 'model_id': self.model_id, 'model_config': self.model_config, 'created_at': self.created_at, 'project_id': self.project_id, 'shared': self.shared, 'shared_at': self.shared_at, 'refresh_schedules': self.refresh_schedules, 'location': [elem.to_dict() for elem in self.location or []], 'latest_model_version': [elem.to_dict() for elem in self.latest_model_version or []]}
+        return {'name': self.name, 'model_id': self.model_id, 'model_config': self.model_config, 'created_at': self.created_at, 'project_id': self.project_id, 'shared': self.shared, 'shared_at': self.shared_at, 'location': [elem.to_dict() for elem in self.location or []], 'refresh_schedules': self.refresh_schedules.to_dict() if self.refresh_schedules else None, 'latest_model_version': [elem.to_dict() for elem in self.latest_model_version or []]}
 
     def refresh(self):
-        self = self.describe()
+        self.__dict__.update(self.describe().__dict__)
         return self
 
     def describe(self):
         return self.client.describe_model(self.model_id)
 
+    def rename(self, name):
+        return self.client.rename_model(self.model_id, name)
+
     def update_training_config(self, training_config):
         return self.client.update_model_training_config(self.model_id, training_config)
 
+    def set_training_config(self, training_config):
+        return self.client.set_model_training_config(self.model_id, training_config)
+
     def get_metrics(self, model_version=None, baseline_metrics=False):
         return self.client.get_model_metrics(self.model_id, model_version, baseline_metrics)
 
@@ -50,24 +58,12 @@ class Model():
     def retrain(self, deployment_ids=[]):
         return self.client.retrain_model(self.model_id, deployment_ids)
 
-    def cancel_training(self):
-        return self.client.cancel_model_training(self.model_id)
-
     def delete(self):
         return self.client.delete_model(self.model_id)
 
     def create_deployment(self, name=None, description=None, calls_per_second=None, auto_deploy=True):
         return self.client.create_deployment(self.model_id, name, description, calls_per_second, auto_deploy)
 
-    def upsert_item_embeddings(self, item_id, vector):
-        return self.client.upsert_item_embeddings(self.model_id, item_id, vector)
-
-    def delete_item_embeddings(self, item_ids):
-        return self.client.delete_item_embeddings(self.model_id, item_ids)
-
-    def upsert_multiple_item_embeddings(self, upserts):
-        return self.client.upsert_multiple_item_embeddings(self.model_id, upserts)
-
     def wait_for_training(self, timeout=None):
         return self.client._poll(self, {'PENDING', 'TRAINING'}, delay=30, timeout=timeout)
 
